@@ -10,6 +10,7 @@ use super::{
     },
     ObjectsManager,
 };
+use assert_impl::assert_impl;
 use mime::Mime;
 use once_cell::sync::OnceCell;
 use qiniu_apis::{
@@ -78,7 +79,7 @@ impl Bucket {
     ///
     /// # fn example() -> anyhow::Result<()> {
     /// let credential = Credential::new("abcdefghklmnopq", "1234567890");
-    /// let object_manager = ObjectsManager::builder(credential).build();
+    /// let object_manager = ObjectsManager::new(credential);
     /// let bucket = object_manager.bucket("test-bucket");
     /// let mut iter = bucket.list().iter();
     /// while let Some(object) = iter.next() {
@@ -99,7 +100,7 @@ impl Bucket {
     ///
     /// # async fn example() -> anyhow::Result<()> {
     /// let credential = Credential::new("abcdefghklmnopq", "1234567890");
-    /// let object_manager = ObjectsManager::builder(credential).build();
+    /// let object_manager = ObjectsManager::new(credential);
     /// let bucket = object_manager.bucket("test-bucket");
     /// let mut stream = bucket.list().stream();
     /// while let Some(object) = stream.try_next().await? {
@@ -124,7 +125,7 @@ impl Bucket {
     ///
     /// # fn example() -> anyhow::Result<()> {
     /// let credential = Credential::new("abcdefghklmnopq", "1234567890");
-    /// let object_manager = ObjectsManager::builder(credential).build();
+    /// let object_manager = ObjectsManager::new(credential);
     /// let bucket = object_manager.bucket("test-bucket");
     ///
     /// let response = bucket.stat_object("test-key").call()?;
@@ -143,7 +144,7 @@ impl Bucket {
     ///
     /// # async fn example() -> anyhow::Result<()> {
     /// let credential = Credential::new("abcdefghklmnopq", "1234567890");
-    /// let object_manager = ObjectsManager::builder(credential).build();
+    /// let object_manager = ObjectsManager::new(credential);
     /// let bucket = object_manager.bucket("test-bucket");
     ///
     /// let response = bucket.stat_object("test-key").async_call().await?;
@@ -168,7 +169,7 @@ impl Bucket {
     ///
     /// # fn example() -> anyhow::Result<()> {
     /// let credential = Credential::new("abcdefghklmnopq", "1234567890");
-    /// let object_manager = ObjectsManager::builder(credential).build();
+    /// let object_manager = ObjectsManager::new(credential);
     /// let bucket = object_manager.bucket("test-bucket");
     ///
     /// bucket.copy_object_to("test-key", "test-bucket-2", "test-key").call()?;
@@ -183,7 +184,7 @@ impl Bucket {
     ///
     /// # async fn example() -> anyhow::Result<()> {
     /// let credential = Credential::new("abcdefghklmnopq", "1234567890");
-    /// let object_manager = ObjectsManager::builder(credential).build();
+    /// let object_manager = ObjectsManager::new(credential);
     /// let bucket = object_manager.bucket("test-bucket");
     ///
     /// bucket.copy_object_to("test-key", "test-bucket-2", "test-key").async_call().await?;
@@ -209,7 +210,7 @@ impl Bucket {
     ///
     /// # fn example() -> anyhow::Result<()> {
     /// let credential = Credential::new("abcdefghklmnopq", "1234567890");
-    /// let object_manager = ObjectsManager::builder(credential).build();
+    /// let object_manager = ObjectsManager::new(credential);
     /// let bucket = object_manager.bucket("test-bucket");
     ///
     /// bucket.move_object_to("test-key", "test-bucket-2", "test-key").call()?;
@@ -224,7 +225,7 @@ impl Bucket {
     ///
     /// # async fn example() -> anyhow::Result<()> {
     /// let credential = Credential::new("abcdefghklmnopq", "1234567890");
-    /// let object_manager = ObjectsManager::builder(credential).build();
+    /// let object_manager = ObjectsManager::new(credential);
     /// let bucket = object_manager.bucket("test-bucket");
     ///
     /// bucket.move_object_to("test-key", "test-bucket-2", "test-key").async_call().await?;
@@ -250,7 +251,7 @@ impl Bucket {
     ///
     /// # fn example() -> anyhow::Result<()> {
     /// let credential = Credential::new("abcdefghklmnopq", "1234567890");
-    /// let object_manager = ObjectsManager::builder(credential).build();
+    /// let object_manager = ObjectsManager::new(credential);
     /// let bucket = object_manager.bucket("test-bucket");
     ///
     /// bucket.delete_object("test-key").call()?;
@@ -265,7 +266,7 @@ impl Bucket {
     ///
     /// # async fn example() -> anyhow::Result<()> {
     /// let credential = Credential::new("abcdefghklmnopq", "1234567890");
-    /// let object_manager = ObjectsManager::builder(credential).build();
+    /// let object_manager = ObjectsManager::new(credential);
     /// let bucket = object_manager.bucket("test-bucket");
     ///
     /// bucket.delete_object("test-key").async_call().await?;
@@ -286,7 +287,7 @@ impl Bucket {
     ///
     /// # fn example() -> anyhow::Result<()> {
     /// let credential = Credential::new("abcdefghklmnopq", "1234567890");
-    /// let object_manager = ObjectsManager::builder(credential).build();
+    /// let object_manager = ObjectsManager::new(credential);
     /// let bucket = object_manager.bucket("test-bucket");
     ///
     /// bucket.restore_archived_object("test-key", 1).call()?;
@@ -301,7 +302,7 @@ impl Bucket {
     ///
     /// # async fn example() -> anyhow::Result<()> {
     /// let credential = Credential::new("abcdefghklmnopq", "1234567890");
-    /// let object_manager = ObjectsManager::builder(credential).build();
+    /// let object_manager = ObjectsManager::new(credential);
     /// let bucket = object_manager.bucket("test-bucket");
     ///
     /// bucket.restore_archived_object("test-key", 1).async_call().await?;
@@ -326,7 +327,7 @@ impl Bucket {
     ///
     /// # fn example() -> anyhow::Result<()> {
     /// let credential = Credential::new("abcdefghklmnopq", "1234567890");
-    /// let object_manager = ObjectsManager::builder(credential).build();
+    /// let object_manager = ObjectsManager::new(credential);
     /// let bucket = object_manager.bucket("test-bucket");
     ///
     /// bucket.set_object_type("test-key", FileType::Archive).call()?;
@@ -341,7 +342,7 @@ impl Bucket {
     ///
     /// # async fn example() -> anyhow::Result<()> {
     /// let credential = Credential::new("abcdefghklmnopq", "1234567890");
-    /// let object_manager = ObjectsManager::builder(credential).build();
+    /// let object_manager = ObjectsManager::new(credential);
     /// let bucket = object_manager.bucket("test-bucket");
     ///
     /// bucket.set_object_type("test-key", FileType::Archive).async_call().await?;
@@ -362,7 +363,7 @@ impl Bucket {
     ///
     /// # async fn example() -> anyhow::Result<()> {
     /// let credential = Credential::new("abcdefghklmnopq", "1234567890");
-    /// let object_manager = ObjectsManager::builder(credential).build();
+    /// let object_manager = ObjectsManager::new(credential);
     /// let bucket = object_manager.bucket("test-bucket");
     ///
     /// bucket.modify_object_status("test-key", true).call()?;
@@ -377,7 +378,7 @@ impl Bucket {
     ///
     /// # async fn example() -> anyhow::Result<()> {
     /// let credential = Credential::new("abcdefghklmnopq", "1234567890");
-    /// let object_manager = ObjectsManager::builder(credential).build();
+    /// let object_manager = ObjectsManager::new(credential);
     /// let bucket = object_manager.bucket("test-bucket");
     ///
     /// bucket.modify_object_status("test-key", true).async_call().await?;
@@ -397,7 +398,7 @@ impl Bucket {
     ///
     /// # async fn example() -> anyhow::Result<()> {
     /// let credential = Credential::new("abcdefghklmnopq", "1234567890");
-    /// let object_manager = ObjectsManager::builder(credential).build();
+    /// let object_manager = ObjectsManager::new(credential);
     /// let bucket = object_manager.bucket("test-bucket");
     ///
     /// bucket.modify_object_metadata("test-key", APPLICATION_JSON).async_call().await?;
@@ -422,7 +423,7 @@ impl Bucket {
     ///
     /// # async fn example() -> anyhow::Result<()> {
     /// let credential = Credential::new("abcdefghklmnopq", "1234567890");
-    /// let object_manager = ObjectsManager::builder(credential).build();
+    /// let object_manager = ObjectsManager::new(credential);
     /// let bucket = object_manager.bucket("test-bucket");
     ///
     /// bucket.modify_object_life_cycle("test-key").delete_after_days(AfterDays::new(5)).call()?;
@@ -437,7 +438,7 @@ impl Bucket {
     ///
     /// # async fn example() -> anyhow::Result<()> {
     /// let credential = Credential::new("abcdefghklmnopq", "1234567890");
-    /// let object_manager = ObjectsManager::builder(credential).build();
+    /// let object_manager = ObjectsManager::new(credential);
     /// let bucket = object_manager.bucket("test-bucket");
     ///
     /// bucket.modify_object_life_cycle("test-key").delete_after_days(AfterDays::new(5)).async_call().await?;
@@ -458,7 +459,7 @@ impl Bucket {
     ///
     /// # fn example() -> anyhow::Result<()> {
     /// let credential = Credential::new("abcdefghklmnopq", "1234567890");
-    /// let object_manager = ObjectsManager::builder(credential).build();
+    /// let object_manager = ObjectsManager::new(credential);
     /// let bucket = object_manager.bucket("test-bucket");
     /// let mut ops = bucket.batch_ops();
     /// ops.add_operation(bucket.stat_object("test-file-1"));
@@ -485,7 +486,7 @@ impl Bucket {
     ///
     /// # async fn example() -> anyhow::Result<()> {
     /// let credential = Credential::new("abcdefghklmnopq", "1234567890");
-    /// let object_manager = ObjectsManager::builder(credential).build();
+    /// let object_manager = ObjectsManager::new(credential);
     /// let bucket = object_manager.bucket("test-bucket");
     /// let mut ops = bucket.batch_ops();
     /// ops.add_operation(bucket.stat_object("test-file-1"));
@@ -557,6 +558,12 @@ impl Bucket {
             ))
         }
     }
+
+    #[allow(dead_code)]
+    fn assert() {
+        assert_impl!(Send: Self);
+        assert_impl!(Sync: Self);
+    }
 }
 
 /// 列举操作构建器
@@ -701,4 +708,10 @@ impl<'a> ListBuilder<'a> {
             callbacks: take(&mut self.callbacks),
         }
     }
+
+    #[allow(dead_code)]
+    fn assert() {
+        assert_impl!(Send: Self);
+        assert_impl!(Sync: Self);
+    }
 }
